@@ -69,7 +69,7 @@ class FaustAgent():
 
   def setup_metrics(self):
     self.metrics.inbound_counter = Counter(
-      'delphai_inbound_counter',
+      f'delphai_{self.agent_id.replace(".", "_")}_inbound_counter',
       'incoming requests',
       const_labels={
         'step': self.step,
@@ -77,7 +77,7 @@ class FaustAgent():
       },
     )
     self.metrics.processed_counter = Counter(
-      'delphai_processed_counter',
+      f'delphai_{self.agent_id.replace(".", "_")}_processed_counter',
       'processed requests',
       const_labels={
         'step': self.step,
@@ -85,7 +85,7 @@ class FaustAgent():
       },
     )
     self.metrics.lag_timer = Counter(
-      'delphai_lag_timer',
+      f'delphai_{self.agent_id.replace(".", "_")}_lag_timer',
       'time to process requests',
       const_labels={
         'step': self.step,
